# Balance Sheet
A SQL powered personal monthly Balance Sheet you can interact with in the Shell prompt. 

## Usage
You need Python3 and SQLite for this project. If you do not have Python3 installed, I suggest you follow a guide such as [this one](https://realpython.com/installing-python/).  

Your computer probably already comes installed with SQLite, but if not, you can follow the guide [here](https://www.tutorialspoint.com/sqlite/sqlite_installation.htm) to get up and running.  

Once you have both of those, open a new Terminal prompt if you are on a Mac, or shell prompt otherwise. You can clone the repo - meaning copy the code to your own computer - with the command:

```git clone https://github.com/evanaze/balance-sheet.git && cd balance-sheet```


To engage with the program, run:

```python3 -m src.main```  

from the command line, and you will be guided through the steps to use the package.

## Contribution
Contributions are welcome! This is a tool that I use, but it is also an exercise in writing good, Object Oriented Python code. If you would like to make a contribution please submit a pull request.